pygeodesy.geodesicw

Package pygeodesy :: Module geodesicw |
[frames] | no frames]

# Module geodesicw

Wrapper around Python classes `geodesic.Geodesic` and `geodesicline.GeodesicLine` from Karney's Python package geographiclib, provided that package is installed.

The wrapped class methods return a GDict instance offering access to the `dict` items either by `key` or by `attribute` name.

With env variable `PYGEODESY_GEOGRAPHICLIB` left undefined or set to `"2"`, this module and modules pygeodesy.geodesici, pygeodesy.geodesicx and pygeodesy.karney will use GeographicLib 2.0 transcoding, otherwise `1.52` or older.

Version: 25.05.28

Classes
| Geodesic Wrapper around Karney's class geographiclib.geodesic.Geodesic.
| GeodesicLine Wrapper around Karney's class geographiclib.geodesicline.GeodesicLine.

Functions
Geodesic_WGS84() Get the wrapped Geodesic`(WGS84)` singleton, provided geographiclib is installed, otherwise an `ImportError`. |

Variables
| __all__ = `_ALL_LAZY.geodesicw`